==> estateplat-common-1.2.4-20200312.072023-274-sources.jar: cn/gtmap/estateplat/model/information/core/XxCrhb.java <==
package cn.gtmap.estateplat.model.information.core;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2019-12-17
 * @description 国有建设用地使用权出让合同和划拨决定书模型
 */
@Table(name = "xx_crhb")
public class XxCrhb extends XxMxParent implements InsertVo, XxMxVo {
    @Id
    private String ywid;//主键
    @Column
    private String proid;//项目表主键
    @Column
    private String tdsyr;//土地使用人
    @Column
    private String dkbh;//地块编号
    @Column
    private String zdwz;//宗地位置
    @Column
    private Double crje;//出让金额
    @Column
    private Double crmj;//出让（划拨）面积
    @Column
    private String zdyt;//宗地用途
    @Column
    private String tdsyqx;//土地使用期限
    @Column
    private String htbh;//合同编号
    @Column
    private Date htqdsj;//合同签订时间
    @Column
    private String crfs;//出让方式
    @Column
    private String bz; //备注
    @Column
    private String xxgxqk;//信息共享情况

    @Override
    public String getProid() {
        return proid;
    }

    @Override
    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getTdsyr() {
        return tdsyr;
    }

    public void setTdsyr(String tdsyr) {
        this.tdsyr = tdsyr;
    }

    public String getDkbh() {
        return dkbh;
    }

    public void setDkbh(String dkbh) {
        this.dkbh = dkbh;
    }

    public String getZdwz() {
        return zdwz;
    }

    public void setZdwz(String zdwz) {
        this.zdwz = zdwz;
    }

    public Double getCrje() {
        return crje;
    }

    public void setCrje(Double crje) {
        this.crje = crje;
    }

    public Double getCrmj() {
        return crmj;
    }

    public void setCrmj(Double crmj) {
        this.crmj = crmj;
    }

    public String getZdyt() {
        return zdyt;
    }

    public void setZdyt(String zdyt) {
        this.zdyt = zdyt;
    }

    public String getTdsyqx() {
        return tdsyqx;
    }

    public void setTdsyqx(String tdsyqx) {
        this.tdsyqx = tdsyqx;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public Date getHtqdsj() {
        return htqdsj;
    }

    public void setHtqdsj(Date htqdsj) {
        this.htqdsj = htqdsj;
    }

    public String getCrfs() {
        return crfs;
    }

    public void setCrfs(String crfs) {
        this.crfs = crfs;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getXxgxqk() {
        return xxgxqk;
    }

    public void setXxgxqk(String xxgxqk) {
        this.xxgxqk = xxgxqk;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }


    @Override
    public void setDwmc(String dwmc) {
        super.dwmc = "XXXX";
    }

    @Override
    public void setDwbm(String dwbm) {
        super.dwbm = "XXXX";
    }

    @Override
    public void setMxlx(String mxlx) {
        super.mxlx = "crhb";
    }
}

==> estateplat-common-1.2.4-20210421.020117-726-sources.jar: cn/gtmap/estateplat/model/information/core/XxCrhb.java <==
package cn.gtmap.estateplat.model.information.core;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2019-12-17
 * @description 国有建设用地使用权出让合同和划拨决定书模型
 */
@Table(name = "xx_crhb")
public class XxCrhb extends XxMxParent implements InsertVo, XxMxVo {
    @Id
    private String ywid;//主键
    @Column
    private String proid;//项目表主键
    @Column
    private String tdsyr;//土地使用人
    @Column
    private String dkbh;//地块编号
    @Column
    private String zdwz;//宗地位置
    @Column
    private Double crje;//出让金额
    @Column
    private Double crmj;//出让（划拨）面积
    @Column
    private String zdyt;//宗地用途
    @Column
    private String tdsyqx;//土地使用期限
    @Column
    private String htbh;//合同编号
    @Column
    private Date htqdsj;//合同签订时间
    @Column
    private String crfs;//出让方式
    @Column
    private String bz; //备注
    @Column
    private String xxgxqk;//信息共享情况
    @Column
    private String tjzt;//提交状态

    public String getTjzt() {
        return tjzt;
    }

    public void setTjzt(String tjzt) {
        this.tjzt = tjzt;
    }

    @Override
    public String getProid() {
        return proid;
    }

    @Override
    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getTdsyr() {
        return tdsyr;
    }

    public void setTdsyr(String tdsyr) {
        this.tdsyr = tdsyr;
    }

    public String getDkbh() {
        return dkbh;
    }

    public void setDkbh(String dkbh) {
        this.dkbh = dkbh;
    }

    public String getZdwz() {
        return zdwz;
    }

    public void setZdwz(String zdwz) {
        this.zdwz = zdwz;
    }

    public Double getCrje() {
        return crje;
    }

    public void setCrje(Double crje) {
        this.crje = crje;
    }

    public Double getCrmj() {
        return crmj;
    }

    public void setCrmj(Double crmj) {
        this.crmj = crmj;
    }

    public String getZdyt() {
        return zdyt;
    }

    public void setZdyt(String zdyt) {
        this.zdyt = zdyt;
    }

    public String getTdsyqx() {
        return tdsyqx;
    }

    public void setTdsyqx(String tdsyqx) {
        this.tdsyqx = tdsyqx;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public Date getHtqdsj() {
        return htqdsj;
    }

    public void setHtqdsj(Date htqdsj) {
        this.htqdsj = htqdsj;
    }

    public String getCrfs() {
        return crfs;
    }

    public void setCrfs(String crfs) {
        this.crfs = crfs;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getXxgxqk() {
        return xxgxqk;
    }

    public void setXxgxqk(String xxgxqk) {
        this.xxgxqk = xxgxqk;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }


    @Override
    public void setDwmc(String dwmc) {
        super.dwmc = "XXXX";
    }

    @Override
    public void setDwbm(String dwbm) {
        super.dwbm = "XXXX";
    }

    @Override
    public void setMxlx(String mxlx) {
        super.mxlx = "crhb";
    }
}
